@@ -15,7 +15,7 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -147,6 +147,9 @@ sub _serialize {
 				push @ret, $key.'.'.$subkey;
 			}
 		} else {
+			if ($config_hr->{$key} =~ m/\n/ms) {
+				err 'Unsupported stay with newline in value.';
+			}
 			push @ret, $key.'='.$config_hr->{$key};
 		}
 	}
@@ -176,13 +179,13 @@ Config::Dot - Module for simple configure file parsing.
 
 =over 8
 
-=item B<new(%params)>
+=item C<new(%params)>
 
  Constructor.
 
 =over 8
 
-=item * B<callback>
+=item * C<callback>
 
  Callback code for adding parameter.
  Callback arguments are:
@@ -190,29 +193,29 @@ Config::Dot - Module for simple configure file parsing.
  $value - Key value.
  Default is undef.
 
-=item * B<config>
+=item * C<config>
 
  Reference to hash structure with default config data.
  This is hash of hashes structure.
  Default value is reference to blank hash.
 
-=item * B<set_conflicts>
+=item * C<set_conflicts>
 
  Set conflicts detection as error.
  Default value is 1.
 
 =back
 
-=item B<parse($string_or_array_ref)>
+=item C<parse($string_or_array_ref)>
 
 Parse string $string_or_array_ref or reference to array 
 $string_or_array_ref and returns hash structure.
 
-=item B<reset()>
+=item C<reset()>
 
 Reset content in class (config parameter).
 
-=item B<serialize()>
+=item C<serialize()>
 
 Serialize 'config' hash to output.
 
@@ -234,15 +237,19 @@ Serialize 'config' hash to output.
 
 =head1 ERRORS
 
- Mine:
+ new():
          Bad 'config' parameter.
          Parameter 'callback' isn't code reference.
+         From Class::Utils::set_params():
+                 Unknown parameter '%s'.
 
- From Class::Utils::set_params():
-         Unknown parameter '%s'.
+ parse():
+         Bad key '%s' in string '%s' at line '%s'.
+         From Config::Utils::hash():
+                  Conflict in '%s'.
 
- From Config::Utils::conflict():
-         Conflict in '%s'.
+ serialize():
+         Unsupported stay with newline in value.
 
 =head1 EXAMPLE1
 
@@ -364,6 +371,6 @@ BSD license.
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
